"use strict";
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const winston_transport_1 = __importDefault(require("winston-transport"));
const Sentry = __importStar(require("@sentry/node"));
class SentryTransport extends winston_transport_1.default {
    constructor(opts) {
        const { sentry } = opts, rest = __rest(opts, ["sentry"]);
        super(rest);
        Sentry.init(sentry);
    }
    log(info, next) {
        if (this.silent) {
            next();
            return;
        }
        if (typeof info.extra !== 'undefined') {
            this.setExtra(info.extra);
        }
        if (typeof info.tags !== 'undefined') {
            this.setTag(info.tags);
        }
        if (typeof info.user !== 'undefined') {
            this.setUserInfo(info.user);
        }
        this.setLevel(this.getLevel(info.level));
        if (info instanceof Error) {
            this.setExtra({
                stack: info.stack,
                message: info.message,
            });
            Sentry.captureException(info);
        }
        else if (info.exception && this.handleExceptions) {
            this.setExtra(info);
            Sentry.captureException(info.error);
        }
        else {
            Sentry.captureMessage(info.message);
        }
        next();
    }
    setLevel(level) {
        Sentry.configureScope((scope) => {
            scope.setLevel(this.getLevel(level));
        });
    }
    setExtra(extra) {
        Sentry.configureScope((scope) => {
            Object.entries(extra).forEach((e) => {
                scope.setExtra(e[0], e[1]);
            });
        });
    }
    setTag(tag) {
        Sentry.configureScope((scope) => {
            Object.entries(tag).forEach((t) => {
                scope.setTag(t[0], t[1]);
            });
        });
    }
    setUserInfo(user) {
        Sentry.configureScope((scope) => {
            scope.setUser(user);
        });
    }
    getLevel(level) {
        switch (level) {
            case 'silly':
            case 'verbose':
            case 'debug':
                return Sentry.Severity.Debug;
            case 'log':
                return Sentry.Severity.Log;
            case 'info':
                return Sentry.Severity.Info;
            case 'warning':
                return Sentry.Severity.Warning;
            case 'error':
                return Sentry.Severity.Error;
            case 'fatal':
                return Sentry.Severity.Fatal;
            default:
                return Sentry.Severity.Error;
        }
    }
}
exports.SentryTransport = SentryTransport;
//# sourceMappingURL=index.js.map